@@ -1,8 +1,8 @@
-use crate::abutton::mybutton::MyButton;
+use crate::mybutton::{MyButton,remove_quotation};
 use crate::spider::get_the_key;
 use cursive::view::{Nameable, Resizable, Scrollable};
 use cursive::views::{
-    Button, Dialog, DummyView, EditView, LinearLayout, NamedView, ResizedView, ScrollView,
+    Button, Dialog, DummyView, EditView, LinearLayout,
     SelectView,
 };
 use cursive::Cursive;
@@ -17,7 +17,7 @@ fn create_storage_before() {
     let home = env::var("HOME").unwrap();
     fs::create_dir_all(home + "/.config/tv2ray").unwrap();
 }
-fn url_select() -> ResizedView<ScrollView<NamedView<SelectView<MyButton>>>> {
+fn url_select() -> impl Resizable {
     let mut start = SelectView::<MyButton>::new().on_submit(on_submit);
     create_storage_before();
     let home = env::var("HOME").unwrap();
@@ -30,14 +30,14 @@ fn url_select() -> ResizedView<ScrollView<NamedView<SelectView<MyButton>>>> {
             let path2 = Path::new(location.as_str());
             let display2 = path2.display();
             let mut file2 = match File::create(&path2) {
-                Err(why) => panic!("couldn't create {}: {}", display2, why.to_string()),
+                Err(why) => panic!("couldn't create {}: {}", display2, why),
                 Ok(file2) => file2,
             };
             let mut storge2: String = String::new();
             storge2.push_str("[]");
             // 将 `LOREM_IPSUM` 字符串写进 `file`，返回 `io::Result<()>`
             if let Err(why) = file2.write_all(storge2.as_bytes()) {
-                panic!("couldn't write to {}: {}", display2, why.to_string())
+                panic!("couldn't write to {}: {}", display2, why)
             }
             let path3 = Path::new(location.as_str());
             File::open(&path3).unwrap()
@@ -69,7 +69,7 @@ fn url_select() -> ResizedView<ScrollView<NamedView<SelectView<MyButton>>>> {
                     typpe: v[index]["type"].to_string(),
                 };
                 let names = v[index]["ps"].to_string();
-                start.add_item(names, url);
+                start.add_item(remove_quotation(names), url);
                 index += 1;
             }
         }
@@ -185,11 +185,12 @@ fn add_name(s: &mut Cursive) {
                     let names = temp2.clone().ps;
                     view.add_item(names, temp2);
                 }
-                storge.pop();
-                storge.pop();
-                storge.push('\n');
-                storge.push(']');
             }
+            storge.pop();
+            storge.pop();
+            storge.push('\n');
+            storge.push(']');
+
             //Get the Home
             let home = env::var("HOME").unwrap();
             let location = home + "/.config/tv2ray/storage.json";
@@ -198,13 +199,13 @@ fn add_name(s: &mut Cursive) {
             //let path2 = Path::new("storage.json");
             let display2 = path2.display();
             let mut file2 = match File::create(&path2) {
-                Err(why) => panic!("couldn't create {}: {}", display2, why.to_string()),
+                Err(why) => panic!("couldn't create {}: {}", display2, why),
                 Ok(file2) => file2,
             };
 
             // 将 `LOREM_IPSUM` 字符串写进 `file`，返回 `io::Result<()>`
             if let Err(why) = file2.write_all(storge.as_bytes()) {
-                panic!("couldn't write to {}: {}", display2, why.to_string())
+                panic!("couldn't write to {}: {}", display2, why)
             }
         });
         s.pop_layer();
@@ -248,13 +249,13 @@ pub fn v2core() -> Dialog {
         //let path2 = Path::new("storage.json");
         let display2 = path2.display();
         let mut file2 = match File::create(&path2) {
-            Err(why) => panic!("couldn't create {}: {}", display2, why.to_string()),
+            Err(why) => panic!("couldn't create {}: {}", display2, why),
             Ok(file2) => file2,
         };
 
         // 将 `LOREM_IPSUM` 字符串写进 `file`，返回 `io::Result<()>`
         if let Err(why) = file2.write_all(output.as_bytes()) {
-            panic!("couldn't write to {}: {}", display2, why.to_string())
+            panic!("couldn't write to {}: {}", display2, why)
         }
     }
     create_storage_before();
@@ -268,14 +269,14 @@ pub fn v2core() -> Dialog {
             let path2 = Path::new(location.as_str());
             let display2 = path2.display();
             let mut file2 = match File::create(&path2) {
-                Err(why) => panic!("couldn't create {}: {}", display2, why.to_string()),
+                Err(why) => panic!("couldn't create {}: {}", display2, why),
                 Ok(file2) => file2,
             };
             let mut storge2: String = String::new();
             storge2.push_str("{\n\"v2core\":\"/usr/bin/v2ray\"\n}");
             // 将 `LOREM_IPSUM` 字符串写进 `file`，返回 `io::Result<()>`
             if let Err(why) = file2.write_all(storge2.as_bytes()) {
-                panic!("couldn't write to {}: {}", display2, why.to_string())
+                panic!("couldn't write to {}: {}", display2, why)
             }
             let path3 = Path::new(location.as_str());
             File::open(&path3).unwrap()
@@ -320,7 +321,7 @@ fn onload(s: &mut Cursive) {
     let display = path.display();
     let mut file = match File::open(&path) {
         // `io::Error` 的 `description` 方法返回一个描述错误的字符串。
-        Err(why) => panic!("couldn't open {}: {}", display, why.to_string()),
+        Err(why) => panic!("couldn't open {}: {}", display, why),
         Ok(file) => file,
     };
     let mut ss = String::new();
@@ -348,7 +349,7 @@ fn onload(s: &mut Cursive) {
                         tls: v[index]["tls"].to_string(),
                         typpe: v[index]["type"].to_string(),
                     };
-                    let names = v[index]["ps"].to_string();
+                    let names = url.get_name();
                     view.add_item(names, url);
                     index += 1;
                 }
